pub enum TrailingInput {
Prohibit,
Discard,
}Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Whether trailing input after the declared end is permitted.
Variants
Prohibit
Trailing input is not permitted and will cause an error.
Discard
Trailing input is permitted but discarded.