WeekdayRepr

Enum WeekdayRepr 

#[non_exhaustive]
pub enum WeekdayRepr { Short, Long, Sunday, Monday, }
๐Ÿ‘ŽDeprecated since 0.3.48:

used only in the deprecated Weekday component

Available on crate feature cookies and (crate features formatting or parsing) only.
The representation used for the day of the week.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Short

๐Ÿ‘ŽDeprecated since 0.3.48:

used only in the deprecated Weekday component

The short form of the weekday (e.g. โ€œMonโ€).



Long

๐Ÿ‘ŽDeprecated since 0.3.48:

used only in the deprecated Weekday component

The long form of the weekday (e.g. โ€œMondayโ€).



Sunday

๐Ÿ‘ŽDeprecated since 0.3.48:

used only in the deprecated Weekday component

A numerical representation using Sunday as the first day of the week.

Sunday is either 0 or 1, depending on the other modifierโ€™s value.



Monday

๐Ÿ‘ŽDeprecated since 0.3.48:

used only in the deprecated Weekday component

A numerical representation using Monday as the first day of the week.

Monday is either 0 or 1, depending on the other modifierโ€™s value.