pub struct CalendarYearCenturyExtendedRange { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. Only the century is included (i.e. all digits except the last two), the calendar year is used, and the range of years supported is ±999,999.
Implementations
Sourceimpl CalendarYearCenturyExtendedRange
impl CalendarYearCenturyExtendedRange
Sourcepub const fn default() -> CalendarYearCenturyExtendedRange
pub const fn default() -> CalendarYearCenturyExtendedRange
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl CalendarYearCenturyExtendedRange
impl CalendarYearCenturyExtendedRange
Sourcepub const fn with_padding(
self,
padding: Padding,
) -> CalendarYearCenturyExtendedRange
pub const fn with_padding( self, padding: Padding, ) -> CalendarYearCenturyExtendedRange
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> CalendarYearCenturyExtendedRange
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> CalendarYearCenturyExtendedRange
Set whether the + sign is mandatory for non-negative years with more than four digits.