pub struct CalendarYearCenturyStandardRange { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. Only the century is included (i.e. all digits except the last two), the calendar year is used, and the range of years supported is ±9,999.
Implementations
Sourceimpl CalendarYearCenturyStandardRange
impl CalendarYearCenturyStandardRange
Sourcepub const fn default() -> CalendarYearCenturyStandardRange
pub const fn default() -> CalendarYearCenturyStandardRange
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl CalendarYearCenturyStandardRange
impl CalendarYearCenturyStandardRange
Sourcepub const fn with_padding(
self,
padding: Padding,
) -> CalendarYearCenturyStandardRange
pub const fn with_padding( self, padding: Padding, ) -> CalendarYearCenturyStandardRange
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> CalendarYearCenturyStandardRange
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> CalendarYearCenturyStandardRange
Set whether the + sign is present on non-negative years.