pub struct CalendarYearFullExtendedRange { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. All digits are included, the calendar year is used, and the range of years supported is ±999,999.
Implementations
Sourceimpl CalendarYearFullExtendedRange
impl CalendarYearFullExtendedRange
Sourcepub const fn default() -> CalendarYearFullExtendedRange
pub const fn default() -> CalendarYearFullExtendedRange
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl CalendarYearFullExtendedRange
impl CalendarYearFullExtendedRange
Sourcepub const fn with_padding(
self,
padding: Padding,
) -> CalendarYearFullExtendedRange
pub const fn with_padding( self, padding: Padding, ) -> CalendarYearFullExtendedRange
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> CalendarYearFullExtendedRange
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> CalendarYearFullExtendedRange
Set whether the + sign is mandatory for non-negative years with more than four digits.