pub struct CalendarYearFullStandardRange { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. All digits are included, the calendar year is used, and the range of years supported is ±9,999.
Implementations
Sourceimpl CalendarYearFullStandardRange
impl CalendarYearFullStandardRange
Sourcepub const fn default() -> CalendarYearFullStandardRange
pub const fn default() -> CalendarYearFullStandardRange
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl CalendarYearFullStandardRange
impl CalendarYearFullStandardRange
Sourcepub const fn with_padding(
self,
padding: Padding,
) -> CalendarYearFullStandardRange
pub const fn with_padding( self, padding: Padding, ) -> CalendarYearFullStandardRange
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> CalendarYearFullStandardRange
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> CalendarYearFullStandardRange
Set whether the + sign is present on non-negative years.