#[non_exhaustive]pub struct CalendarYearLastTwo { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. Only the last two digits are included, and the calendar year is used.
Implementations
Sourceimpl CalendarYearLastTwo
impl CalendarYearLastTwo
Sourcepub const fn default() -> CalendarYearLastTwo
pub const fn default() -> CalendarYearLastTwo
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl CalendarYearLastTwo
impl CalendarYearLastTwo
Sourcepub const fn with_padding(self, padding: Padding) -> CalendarYearLastTwo
pub const fn with_padding(self, padding: Padding) -> CalendarYearLastTwo
Set the padding type.