#[non_exhaustive]pub struct Hour {
pub padding: Padding,
pub is_12_hour_clock: bool,
}use Hour12 or Hour24 instead
cookies and (crate features formatting or parsing) only.Expand description
Hour of the day.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.padding: Paddinguse Hour12 or Hour24 instead
The padding to obtain the minimum width.
is_12_hour_clock: booluse Hour12 or Hour24 instead
Is the hour displayed using a 12 or 24-hour clock?
Implementations
Sourceimpl Hour
impl Hour
Sourcepub const fn default() -> Hour
pub const fn default() -> Hour
Creates a modifier that indicates the value is padded with zeroes and has the 24-hour representation.
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.