pub struct Hour12 { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Hour of the day using a 12-hour clock.
Implementations
Sourceimpl Hour12
impl Hour12
Sourcepub const fn default() -> Hour12
pub const fn default() -> Hour12
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.