pub struct IsoYearCenturyStandardRange { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Year of the date. Only the century is included (i.e. all digits except the last two), the ISO week-numbering year is used, and the range of years supported is ±9,999.
Implementations
Sourceimpl IsoYearCenturyStandardRange
impl IsoYearCenturyStandardRange
Sourcepub const fn default() -> IsoYearCenturyStandardRange
pub const fn default() -> IsoYearCenturyStandardRange
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl IsoYearCenturyStandardRange
impl IsoYearCenturyStandardRange
Sourcepub const fn with_padding(self, padding: Padding) -> IsoYearCenturyStandardRange
pub const fn with_padding(self, padding: Padding) -> IsoYearCenturyStandardRange
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> IsoYearCenturyStandardRange
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> IsoYearCenturyStandardRange
Set whether the + sign is present on non-negative years.