pub struct MonthLong { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Month of the year using the long form of the month name (e.g. “January”).
Implementations
Sourceimpl MonthLong
impl MonthLong
Sourcepub const fn default() -> MonthLong
pub const fn default() -> MonthLong
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.