pub struct MonthNumerical { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Month of the year using a numerical representation (e.g. “1” for January).
Implementations
Sourceimpl MonthNumerical
impl MonthNumerical
Sourcepub const fn default() -> MonthNumerical
pub const fn default() -> MonthNumerical
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl MonthNumerical
impl MonthNumerical
Sourcepub const fn with_padding(self, padding: Padding) -> MonthNumerical
pub const fn with_padding(self, padding: Padding) -> MonthNumerical
Set the padding type.