pub struct MonthShort { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Month of the year using the short form of the month name (e.g. “Jan”).
Implementations
Sourceimpl MonthShort
impl MonthShort
Sourcepub const fn default() -> MonthShort
pub const fn default() -> MonthShort
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl MonthShort
impl MonthShort
Sourcepub const fn with_case_sensitive(self, case_sensitive: bool) -> MonthShort
pub const fn with_case_sensitive(self, case_sensitive: bool) -> MonthShort
Set whether the value is case sensitive when parsing.