pub struct UnixTimestampMicrosecond { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
A Unix timestamp in microseconds.
Implementations
Sourceimpl UnixTimestampMicrosecond
impl UnixTimestampMicrosecond
Sourcepub const fn default() -> UnixTimestampMicrosecond
pub const fn default() -> UnixTimestampMicrosecond
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl UnixTimestampMicrosecond
impl UnixTimestampMicrosecond
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> UnixTimestampMicrosecond
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> UnixTimestampMicrosecond
Set whether the + sign is mandatory for non-negative timestamps.