#[non_exhaustive]pub struct WeekNumber {
pub padding: Padding,
pub repr: WeekNumberRepr,
}use WeekNumberIso, WeekNumberSunday, or WeekNumberMonday instead
cookies and (crate features formatting or parsing) only.Expand description
Week within the year.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.padding: Paddinguse WeekNumberIso, WeekNumberSunday, or WeekNumberMonday instead
The padding to obtain the minimum width.
repr: WeekNumberRepruse WeekNumberIso, WeekNumberSunday, or WeekNumberMonday instead
What kind of representation should be used?
Implementations
Sourceimpl WeekNumber
impl WeekNumber
Sourcepub const fn default() -> WeekNumber
pub const fn default() -> WeekNumber
Creates a modifier that indicates that the value is padded with zeroes
and uses the Iso representation.
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl WeekNumber
impl WeekNumber
Sourcepub const fn with_padding(self, padding: Padding) -> WeekNumber
pub const fn with_padding(self, padding: Padding) -> WeekNumber
Set the padding type.
Sourcepub const fn with_repr(self, repr: WeekNumberRepr) -> WeekNumber
pub const fn with_repr(self, repr: WeekNumberRepr) -> WeekNumber
Set the manner in which the week number is represented.