pub struct WeekNumberIso {
pub padding: Padding,
}Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Week within the year using the ISO week calendar.
Week 1 is the week that contains January 4. All weeks begin on a Monday.
Fields
padding: PaddingThe padding to obtain the minimum width.
Implementations
Sourceimpl WeekNumberIso
impl WeekNumberIso
Sourcepub const fn default() -> WeekNumberIso
pub const fn default() -> WeekNumberIso
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl WeekNumberIso
impl WeekNumberIso
Sourcepub const fn with_padding(self, padding: Padding) -> WeekNumberIso
pub const fn with_padding(self, padding: Padding) -> WeekNumberIso
Set the padding type.