pub struct WeekNumberSunday {
pub padding: Padding,
}Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Week within the calendar year.
Week 1 begins on the first Sunday of the calendar year.
Fields
padding: PaddingThe padding to obtain the minimum width.
Implementations
Sourceimpl WeekNumberSunday
impl WeekNumberSunday
Sourcepub const fn default() -> WeekNumberSunday
pub const fn default() -> WeekNumberSunday
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl WeekNumberSunday
impl WeekNumberSunday
Sourcepub const fn with_padding(self, padding: Padding) -> WeekNumberSunday
pub const fn with_padding(self, padding: Padding) -> WeekNumberSunday
Set the padding type.