pub struct WeekdayShort { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
Day of the week using the short form of the weekday (e.g. “Mon”).
Implementations
Sourceimpl WeekdayShort
impl WeekdayShort
Sourcepub const fn default() -> WeekdayShort
pub const fn default() -> WeekdayShort
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl WeekdayShort
impl WeekdayShort
Sourcepub const fn with_case_sensitive(self, case_sensitive: bool) -> WeekdayShort
pub const fn with_case_sensitive(self, case_sensitive: bool) -> WeekdayShort
Set whether the value is case sensitive when parsing.