Struct actix_web::dev::Extensions [−][src]
A type map for request extensions.
All entries into this map must be owned types (or static references).
Implementations
impl Extensions[src]
pub fn new() -> Extensions[src]
Creates an empty Extensions.
pub fn insert<T>(&mut self, val: T) -> Option<T> where
T: 'static, [src]
T: 'static,
Insert an item into the map.
If an item of this type was already stored, it will be replaced and returned.
let mut map = Extensions::new(); assert_eq!(map.insert(""), None); assert_eq!(map.insert(1u32), None); assert_eq!(map.insert(2u32), Some(1u32)); assert_eq!(*map.get::<u32>().unwrap(), 2u32);
pub fn contains<T>(&self) -> bool where
T: 'static, [src]
T: 'static,
Check if map contains an item of a given type.
let mut map = Extensions::new(); assert!(!map.contains::<u32>()); assert_eq!(map.insert(1u32), None); assert!(map.contains::<u32>());
pub fn get<T>(&self) -> Option<&T> where
T: 'static, [src]
T: 'static,
Get a reference to an item of a given type.
let mut map = Extensions::new(); map.insert(1u32); assert_eq!(map.get::<u32>(), Some(&1u32));
pub fn get_mut<T>(&mut self) -> Option<&mut T> where
T: 'static, [src]
T: 'static,
Get a mutable reference to an item of a given type.
let mut map = Extensions::new(); map.insert(1u32); assert_eq!(map.get_mut::<u32>(), Some(&mut 1u32));
pub fn remove<T>(&mut self) -> Option<T> where
T: 'static, [src]
T: 'static,
Remove an item from the map of a given type.
If an item of this type was already stored, it will be returned.
let mut map = Extensions::new(); map.insert(1u32); assert_eq!(map.get::<u32>(), Some(&1u32)); assert_eq!(map.remove::<u32>(), Some(1u32)); assert!(!map.contains::<u32>());
pub fn clear(&mut self)[src]
Clear the Extensions of all inserted extensions.
let mut map = Extensions::new(); map.insert(1u32); assert!(map.contains::<u32>()); map.clear(); assert!(!map.contains::<u32>());
pub fn extend(&mut self, other: Extensions)[src]
Extends self with the items from another Extensions.