Struct actix_web::dev::ResourceMap [−][src]
pub struct ResourceMap { /* fields omitted */ }Implementations
pub fn url_for<U, I>(
&self,
req: &HttpRequest,
name: &str,
elements: U
) -> Result<Url, UrlGenerationError> where
U: IntoIterator<Item = I>,
I: AsRef<str>,
pub fn url_for<U, I>(
&self,
req: &HttpRequest,
name: &str,
elements: U
) -> Result<Url, UrlGenerationError> where
U: IntoIterator<Item = I>,
I: AsRef<str>, Generate url for named resource
Check HttpRequest::url_for()(../struct.HttpRequest.html#method.
url_for) for detailed information.
Returns the name of the route that matches the given path or None if no full match is possible.
Returns the full resource pattern matched against a path or None if no full match is possible.