Trait actix_web::dev::HttpServiceFactory [−][src]
Required methods
fn register(self, config: &mut AppService)[src]
Implementations on Foreign Types
impl<T: HttpServiceFactory> HttpServiceFactory for Vec<T>[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory> HttpServiceFactory for (A,)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory> HttpServiceFactory for (A, B)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory> HttpServiceFactory for (A, B, C)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory> HttpServiceFactory for (A, B, C, D)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory, H: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G, H)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory, H: HttpServiceFactory, I: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G, H, I)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory, H: HttpServiceFactory, I: HttpServiceFactory, J: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G, H, I, J)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory, H: HttpServiceFactory, I: HttpServiceFactory, J: HttpServiceFactory, K: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G, H, I, J, K)[src]
fn register(self, config: &mut AppService)[src]
impl<A: HttpServiceFactory, B: HttpServiceFactory, C: HttpServiceFactory, D: HttpServiceFactory, E: HttpServiceFactory, F: HttpServiceFactory, G: HttpServiceFactory, H: HttpServiceFactory, I: HttpServiceFactory, J: HttpServiceFactory, K: HttpServiceFactory, L: HttpServiceFactory> HttpServiceFactory for (A, B, C, D, E, F, G, H, I, J, K, L)[src]
fn register(self, config: &mut AppService)[src]
Implementors
impl<T> HttpServiceFactory for Resource<T> where
T: ServiceFactory<ServiceRequest, Config = (), Response = ServiceResponse, Error = Error, InitError = ()> + 'static, [src]
T: ServiceFactory<ServiceRequest, Config = (), Response = ServiceResponse, Error = Error, InitError = ()> + 'static,
fn register(mut self: Self, config: &mut AppService)[src]
impl<T> HttpServiceFactory for Scope<T> where
T: ServiceFactory<ServiceRequest, Config = (), Response = ServiceResponse, Error = Error, InitError = ()> + 'static, [src]
T: ServiceFactory<ServiceRequest, Config = (), Response = ServiceResponse, Error = Error, InitError = ()> + 'static,