Enum actix_web::error::JsonPayloadError [−][src]
#[non_exhaustive]
pub enum JsonPayloadError {
OverflowKnownLength {
length: usize,
limit: usize,
},
Overflow {
limit: usize,
},
ContentType,
Deserialize(JsonError),
Serialize(JsonError),
Payload(PayloadError),
}Expand description
A set of errors that can occur during parsing json payloads
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Payload size is bigger than allowed & content length header set. (default: 2MB)
Payload size is bigger than allowed but no content length header set. (default: 2MB)
Show fields
Fields of Overflow
limit: usizeContent type error
Deserialize(JsonError)Deserialize error
Serialize(JsonError)Serialize error
Payload(PayloadError)Payload error