pub struct Not<G>(pub G);
Wraps a guard and inverts the outcome of its Guard implementation.
The handler below will be called for any request method apart from GET.
use actix_web::{guard, web, HttpResponse};
web::route()
.guard(guard::Not(guard::Get()))
.to(|| HttpResponse::Ok());
Returns true if predicate condition is met for a given request.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.