pub enum ContentRangeSpec {
    Bytes {
        range: Option<(u64, u64)>,
        instance_length: Option<u64>,
    },
    Unregistered {
        unit: String,
        resp: String,
    },
}
Content-Range header, defined in RFC 7233 4.2

ABNF

Content-Range       = byte-content-range
                    / other-content-range

byte-content-range  = bytes-unit SP
                      ( byte-range-resp / unsatisfied-range )

byte-range-resp     = byte-range "/" ( complete-length / "*" )
byte-range          = first-byte-pos "-" last-byte-pos
unsatisfied-range   = "*/" complete-length

complete-length     = 1*DIGIT

other-content-range = other-range-unit SP other-range-resp
other-range-resp    = *CHAR

Variants



Bytes

Fields

range: Option<(u64, u64)>

First and last bytes of the range, omitted if request could not be satisfied

instance_length: Option<u64>

Total length of the instance, can be omitted if unknown

Byte range



Unregistered

Fields

unit: String

other-range-unit

resp: String

other-range-resp

Custom range, with unit not registered at IANA