Enum actix_web::http::header::DispositionType [−][src]
pub enum DispositionType {
Inline,
Attachment,
FormData,
Ext(String),
}Expand description
The implied disposition of the content of the HTTP body.
Variants
Inline implies default processing
Attachment implies that the recipient should prompt the user to save the response locally, rather than process it normally (as per its media type).
Used in multipart/form-data as defined in RFC7578 to carry the field name and the file name.
Ext(String)Extension type. Should be handled by recipients the same way as Attachment