pub enum Encoding {
Known(ContentEncoding),
Unknown(String),
}Expand description
A value to represent an encoding used in the Accept-Encoding and Content-Encoding header.
Variants
Known(ContentEncoding)
A supported content encoding. See ContentEncoding for variants.
Unknown(String)
Some other encoding that is less common, can be any string.
Implementations