pub enum IfMatch {
Any,
Items(Vec<EntityTag>),
}Expand description
If-Match header, defined
in RFC 7232 3.1
The If-Match header field makes the request method conditional on
the recipient origin server either having at least one current
representation of the target resource, when the field-value is “*”,
or having a current representation of the target resource that has an
entity-tag matching a member of the list of entity-tags provided in
the field-value.
An origin server MUST use the strong comparison function when
comparing entity-tags for If-Match, since the client
intends this precondition to prevent the method from being applied if
there have been any changes to the representation data.
Note
This is a request header used for conditional requests (typically to avoid lost updates).
Servers should not send If-Match in responses; use ETag to describe the
current representation instead.
ABNF
If-Match = "*" / 1#entity-tagExample Values
"xyzzy"- “xyzzy”, “r2d2xxxx”, “c3piozzzz”
Examples
use actix_web::{http::header::IfMatch, test};
let req = test::TestRequest::default()
.insert_header(IfMatch::Any)
.to_http_request();use actix_web::{http::header::{EntityTag, IfMatch}, test};
let req = test::TestRequest::default()
.insert_header(IfMatch::Items(vec![
EntityTag::new(false, "xyzzy".to_owned()),
EntityTag::new(false, "foobar".to_owned()),
EntityTag::new(false, "bazquux".to_owned()),
]))
.to_http_request();Variants