pub enum IfNoneMatch {
Any,
Items(Vec<EntityTag>),
}Expand description
If-None-Match header, defined
in RFC 7232 3.2
The If-None-Match header field makes the request method conditional
on a recipient cache or origin server either not having any current
representation of the target resource, when the field-value is “*”,
or having a selected representation with an entity-tag that does not
match any of those listed in the field-value.
A recipient MUST use the weak comparison function when comparing entity-tags for If-None-Match (Section 2.3.2), since weak entity-tags can be used for cache validation even if there have been changes to the representation data.
Note
This is a request header used for cache validation (and conditional requests). Servers
should not send If-None-Match in responses; use ETag to describe the
current representation instead.
ABNF
If-None-Match = "*" / 1#entity-tagExample Values
"xyzzy"W/"xyzzy""xyzzy", "r2d2xxxx", "c3piozzzz"W/"xyzzy", W/"r2d2xxxx", W/"c3piozzzz"*
Examples
use actix_web::{http::header::IfNoneMatch, test};
let req = test::TestRequest::default()
.insert_header(IfNoneMatch::Any)
.to_http_request();use actix_web::{http::header::{EntityTag, IfNoneMatch}, test};
let req = test::TestRequest::default()
.insert_header(IfNoneMatch::Items(vec![
EntityTag::new(false, "xyzzy".to_owned()),
EntityTag::new(false, "foobar".to_owned()),
EntityTag::new(false, "bazquux".to_owned()),
]))
.to_http_request();Variants