Struct actix_web::http::header::AcceptCharset [−][src]
pub struct AcceptCharset(pub Vec<QualityItem<Charset>>);
Accept-Charset header, defined in
RFC7231
The Accept-Charset header field can be sent by a user agent to
indicate what charsets are acceptable in textual response content.
This field allows user agents capable of understanding more
comprehensive or special-purpose charsets to signal that capability
to an origin server that is capable of representing information in
those charsets.
ABNF
Accept-Charset = 1#( ( charset / "*" ) [ weight ] )
Example values
iso-8859-5, unicode-1-1;q=0.8
Examples
use actix_web::HttpResponse; use actix_web::http::header::{AcceptCharset, Charset, qitem}; let mut builder = HttpResponse::Ok(); builder.insert_header( AcceptCharset(vec![qitem(Charset::Us_Ascii)]) );
use actix_web::HttpResponse; use actix_web::http::header::{AcceptCharset, Charset, q, QualityItem}; let mut builder = HttpResponse::Ok(); builder.insert_header( AcceptCharset(vec![ QualityItem::new(Charset::Us_Ascii, q(900)), QualityItem::new(Charset::Iso_8859_10, q(200)), ]) );
use actix_web::HttpResponse; use actix_web::http::header::{AcceptCharset, Charset, qitem}; let mut builder = HttpResponse::Ok(); builder.insert_header( AcceptCharset(vec![qitem(Charset::Ext("utf-8".to_owned()))]) );