Struct actix_web::http::header::Allow [−][src]
Allow header, defined in RFC7231
The Allow header field lists the set of methods advertised as
supported by the target resource. The purpose of this field is
strictly to inform the recipient of valid request methods associated
with the resource.
ABNF
Allow = #method
Example values
GET, HEAD, PUTOPTIONS, GET, PUT, POST, DELETE, HEAD, TRACE, CONNECT, PATCH, fOObAr- ``
Examples
use actix_web::HttpResponse; use actix_web::http::{header::Allow, Method}; let mut builder = HttpResponse::Ok(); builder.insert_header( Allow(vec![Method::GET]) );
use actix_web::HttpResponse; use actix_web::http::{header::Allow, Method}; let mut builder = HttpResponse::Ok(); builder.insert_header( Allow(vec![ Method::GET, Method::POST, Method::PATCH, ]) );