pub struct LastModified(pub HttpDate);Expand description
Last-Modified header, defined
in RFC 7232 2.2
The Last-Modified header field in a response provides a timestamp
indicating the date and time at which the origin server believes the
selected representation was last modified, as determined at the
conclusion of handling the request.
ABNF
Expires = HTTP-dateExample Values
Sat, 29 Oct 1994 19:43:31 GMT
Examples
use std::time::{SystemTime, Duration};
use actix_web::HttpResponse;
use actix_web::http::header::LastModified;
let mut builder = HttpResponse::Ok();
let modified = SystemTime::now() - Duration::from_secs(60 * 60 * 24);
builder.insert_header(
LastModified(modified.into())
);Tuple Fields
0: HttpDateTrait Implementations
Returns the name of the header field.
Parse the header from a HTTP message.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
The type returned in the event of a conversion error.
Try to convert value to a HeaderValue.