Struct actix_web::middleware::Condition [−][src]
pub struct Condition<T> { /* fields omitted */ }Expand description
Middleware for conditionally enables another middleware.
The controlled middleware must not change the Service interfaces.
This means you cannot control such middlewares like Logger or Compress.
Usage
use actix_web::middleware::{Condition, NormalizePath};
use actix_web::App;
let enable_normalize = std::env::var("NORMALIZE_PATH") == Ok("true".into());
let app = App::new()
.wrap(Condition::new(enable_normalize, NormalizePath::default()));Implementations