#[non_exhaustive]pub struct Month {
pub padding: Padding,
pub repr: MonthRepr,
pub case_sensitive: bool,
}use MonthShort, MonthLong, or MonthNumeric instead
cookies and (crate features formatting or parsing) only.Expand description
Month of the year.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.padding: Paddinguse MonthShort, MonthLong, or MonthNumeric instead
The padding to obtain the minimum width.
repr: MonthRepruse MonthShort, MonthLong, or MonthNumeric instead
What form of representation should be used?
case_sensitive: booluse MonthShort, MonthLong, or MonthNumeric instead
Is the value case sensitive when parsing?
Implementations
Sourceimpl Month
impl Month
Sourcepub const fn default() -> Month
pub const fn default() -> Month
Creates an instance of this type that indicates the value uses the
Numerical representation, is padded with zeroes,
and is case-sensitive when parsing.
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl Month
impl Month
Sourcepub const fn with_padding(self, padding: Padding) -> Month
pub const fn with_padding(self, padding: Padding) -> Month
Set the padding type.
Sourcepub const fn with_repr(self, repr: MonthRepr) -> Month
pub const fn with_repr(self, repr: MonthRepr) -> Month
Set the manner in which the month is represented.
Sourcepub const fn with_case_sensitive(self, case_sensitive: bool) -> Month
pub const fn with_case_sensitive(self, case_sensitive: bool) -> Month
Set whether the value is case sensitive when parsing.