pub struct UnixTimestampMillisecond { /* private fields */ }Available on crate feature
cookies and (crate features formatting or parsing) only.Expand description
A Unix timestamp in milliseconds.
Implementations
Sourceimpl UnixTimestampMillisecond
impl UnixTimestampMillisecond
Sourcepub const fn default() -> UnixTimestampMillisecond
pub const fn default() -> UnixTimestampMillisecond
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl UnixTimestampMillisecond
impl UnixTimestampMillisecond
Sourcepub const fn with_sign_is_mandatory(
self,
sign_is_mandatory: bool,
) -> UnixTimestampMillisecond
pub const fn with_sign_is_mandatory( self, sign_is_mandatory: bool, ) -> UnixTimestampMillisecond
Set whether the + sign is mandatory for non-negative timestamps.