Module actix_web::dev [−][src]
The actix-web prelude for library developers
The purpose of this module is to alleviate imports of many common actix traits by adding a glob import to the top of actix heavy modules:
use actix_web::dev::*;
Structs
| AppConfig | Application connection config |
| AppService | Application configuration |
| ConnectionInfo |
|
| Decompress | |
| Extensions | A type map for request extensions. |
| HttpResponseBuilder | An HTTP response builder. |
| Path | Resource path match information |
| Readlines | Stream that reads request line by line. |
| RequestHead | |
| ResourceDef | ResourceDef describes an entry in resources table |
| ResourceMap | |
| ResponseHead | |
| Server | |
| ServiceRequest | An service http request |
| ServiceResponse | |
| SizedStream | Known sized streaming response wrapper. |
| Url | |
| UrlEncoded | Future that resolves to some |
| WebService |
Enums
| Body | Represents various types of HTTP message body. |
| BodySize | Body size hint. |
| JsonBody | Future that resolves to some |
| Payload | Type represent streaming payload |
| ResponseBody |
Traits
| BodyEncoding | Helper trait that allows to set specific encoding for response. |
| HttpServiceFactory | |
| MessageBody | Type that implement this trait can be streamed to a peer. |
| ResourcePath | |
| Service | An asynchronous operation from |
| Transform | The |
Type Definitions
| PayloadStream | Type represent boxed payload |