Module actix_web::dev
[−]
[src]
The actix-web prelude for library developers
The purpose of this module is to alleviate imports of many common actix traits by adding a glob import to the top of actix heavy modules:
use actix_web::dev::*;
Structs
| ConnectionInfo |
|
| Drain | |
| HttpResponseBuilder |
An HTTP response builder |
| JsonBody |
Request payload json parser that resolves to a deserialized |
| MessageBody |
Future that resolves to a complete http message body. |
| Params |
Route match information |
| Pattern | |
| Router |
Interface for application router. |
| UrlEncoded |
Future that resolves to a parsed urlencoded values. |
Traits
| FromParam |
A trait to abstract the idea of creating a new instance of a type from a path parameter. |
| Handler |
Trait defines object that could be registered as route handler |
Type Definitions
| BodyStream |
Type represent streaming body |