Enum actix_web::dev::EitherCollisionStrategy
source · pub enum EitherCollisionStrategy {
PreferA,
PreferB,
FastestSuccessful,
ErrorA,
ErrorB,
}Expand description
Defines the result if neither or both of the extractors supplied to an Either<A,B> extractor succeed.
Variants
PreferA
If both are successful, return A, if both fail, return error of B
PreferB
If both are successful, return B, if both fail, return error of A
FastestSuccessful
Return result of the faster, error of the slower if both fail
ErrorA
Return error if both succeed, return error of A if both fail
ErrorB
Return error if both succeed, return error of B if both fail