Struct actix_web::dev::ResourceDef [−][src]
pub struct ResourceDef { /* fields omitted */ }Expand description
ResourceDef describes an entry in resources table
Resource definition can contain only 16 dynamic segments
Implementations
Parse path pattern and create new Pattern instance.
Panics if path pattern is malformed.
Parse path pattern and create new Pattern instance.
Use prefix type instead of static.
Panics if path regex pattern is malformed.
Parse path pattern and create new Pattern instance.
Inserts / to begging of the pattern.
Use prefix type instead of static.
Panics if path regex pattern is malformed.
Is prefix path a match against this resource.
Is the given path and parameters a match against this pattern.
Is the given path and parameters a match against this pattern?
Build resource path from elements. Returns true on success.