[−][src]Module actix_web::error
Error and Result module
Structs
| Error | General purpose actix web error. |
| InternalError | Helper type that can wrap any error and generate custom response. |
Enums
| ContentTypeError | A set of error that can occure during parsing content type |
| CookieParseError | Enum corresponding to a parsing error. |
| ExpectError | Error during handling |
| JsonPayloadError | A set of errors that can occur during parsing json payloads |
| MultipartError | A set of errors that can occur during parsing multipart streams |
| ParseError | A set of errors that can occur during parsing HTTP streams |
| PayloadError | A set of errors that can occur during payload parsing |
| ReadlinesError | Error type returned when reading body as lines. |
| StaticFileError | Errors which can occur when serving static files. |
| UriSegmentError | Errors which can occur when attempting to interpret a segment string as a valid path segment. |
| UrlGenerationError | Errors which can occur when attempting to generate resource uri. |
| UrlParseError | Errors that can occur during parsing. |
| UrlencodedError | A set of errors that can occur during parsing urlencoded payloads |
Traits
| ResponseError | Error that can be converted to |
Functions
| ErrorBadGateway | Helper function that creates wrapper of any error and generate BAD GATEWAY response. |
| ErrorBadRequest | Helper function that creates wrapper of any error and generate BAD REQUEST response. |
| ErrorConflict | Helper function that creates wrapper of any error and generate CONFLICT response. |
| ErrorExpectationFailed | Helper function that creates wrapper of any error and generate EXPECTATION FAILED response. |
| ErrorForbidden | Helper function that creates wrapper of any error and generate FORBIDDEN response. |
| ErrorGatewayTimeout | Helper function that creates wrapper of any error and generate GATEWAY TIMEOUT response. |
| ErrorGone | Helper function that creates wrapper of any error and generate GONE response. |
| ErrorInternalServerError | Helper function that creates wrapper of any error and generate INTERNAL SERVER ERROR response. |
| ErrorMethodNotAllowed | Helper function that creates wrapper of any error and generate METHOD NOT ALLOWED response. |
| ErrorNotFound | Helper function that creates wrapper of any error and generate NOT FOUND response. |
| ErrorNotImplemented | Helper function that creates wrapper of any error and generate NOT IMPLEMENTED response. |
| ErrorPreconditionFailed | Helper function that creates wrapper of any error and generate PRECONDITION FAILED response. |
| ErrorRequestTimeout | Helper function that creates wrapper of any error and generate REQUEST TIMEOUT response. |
| ErrorServiceUnavailable | Helper function that creates wrapper of any error and generate SERVICE UNAVAILABLE response. |
| ErrorUnauthorized | Helper function that creates wrapper of any error and generate UNAUTHORIZED response. |
Type Definitions
| Result | A specialized |