pub enum DispositionParam {
Name(String),
Filename(String),
FilenameExt(ExtendedValue),
Unknown(String, String),
UnknownExt(String, ExtendedValue),
}Expand description
Parameter in ContentDisposition.
Examples
use actix_web::http::header::DispositionParam;
let param = DispositionParam::Filename(String::from("sample.txt"));
assert!(param.is_filename());
assert_eq!(param.as_filename().unwrap(), "sample.txt");Variants
Name(String)
For DispositionType::FormData (i.e. multipart/form-data), the name of an field from
the form.
Filename(String)
A plain file name.
It is not supposed to contain
any non-ASCII characters when used in a Content-Disposition HTTP response header, where
FilenameExt with charset UTF-8 may be used instead
in case there are Unicode characters in file names.
FilenameExt(ExtendedValue)
An extended file name. It must not exist for ContentType::Formdata according to
RFC 7578 4.2.
Unknown(String, String)
An unrecognized regular parameter as defined in
RFC 5987 3.2.1 as
reg-parameter, in
RFC 6266 4.1 as
token "=" value. Recipients should ignore unrecognizable parameters.
UnknownExt(String, ExtendedValue)
An unrecognized extended parameter as defined in
RFC 5987 3.2.1 as
ext-parameter, in
RFC 6266 4.1 as
ext-token "=" ext-value. The single trailing asterisk is not included. Recipients should
ignore unrecognizable parameters.
Implementations
Returns true if the parameter is Filename.
Returns true if the parameter is FilenameExt.
Returns true if the parameter is Unknown and the name
matches.
Returns true if the parameter is UnknownExt and the
name matches.
Returns the filename if applicable.
Returns the filename* if applicable.
Returns the value of the unrecognized regular parameter if it is
Unknown and the name matches.
Returns the value of the unrecognized extended parameter if it is
Unknown and the name matches.