Enum actix_web::http::header::Encoding [−][src]
pub enum Encoding {
Chunked,
Brotli,
Gzip,
Deflate,
Compress,
Identity,
Trailers,
Zstd,
EncodingExt(String),
}Expand description
A value to represent an encoding used in Transfer-Encoding
or Accept-Encoding header.
Variants
The chunked encoding.
The br encoding.
The gzip encoding.
The deflate encoding.
The compress encoding.
The identity encoding.
The trailers encoding.
The zstd encoding.
EncodingExt(String)Some other encoding that is less common, can be any String.