Enum actix_web::http::header::Encoding [−][src]
pub enum Encoding {
Chunked,
Brotli,
Gzip,
Deflate,
Compress,
Identity,
Trailers,
EncodingExt(String),
}Expand description
A value to represent an encoding used in Transfer-Encoding
or Accept-Encoding header.
Variants
Chunked
The chunked encoding.
Brotli
The br encoding.
Gzip
The gzip encoding.
Deflate
The deflate encoding.
Compress
The compress encoding.
Identity
The identity encoding.
Trailers
The trailers encoding.
EncodingExt(String)
Tuple Fields
0: StringSome other encoding that is less common, can be any String.