[−][src]Enum actix_web::http::header::Encoding
A value to represent an encoding used in Transfer-Encoding
or Accept-Encoding header.
Variants
The chunked encoding.
The br encoding.
The gzip encoding.
The deflate encoding.
The compress encoding.
The identity encoding.
The trailers encoding.
EncodingExt(String)Some other encoding that is less common, can be any String.