[−][src]Enum actix_web::http::header::Encoding
A value to represent an encoding used in Transfer-Encoding
or Accept-Encoding header.
Variants
ChunkedThe chunked encoding.
BrotliThe br encoding.
GzipThe gzip encoding.
DeflateThe deflate encoding.
CompressThe compress encoding.
IdentityThe identity encoding.
TrailersThe trailers encoding.
EncodingExt(String)Some other encoding that is less common, can be any String.