pub enum Preference<T> {
Any,
Specific(T),
}Expand description
A wrapper for types used in header values where wildcard (*) items are allowed but the
underlying type does not support them.
For example, we use the language-tags crate for the AcceptLanguage
typed header but it does not parse * successfully. On the other hand, the mime crate, used
for Accept, has first-party support for wildcard items so this wrapper is not
used in those header types.
Variants
Any
A wildcard value.
Specific(T)
A valid T.
Implementations
Returns true if preference is the specific item (T) variant.