Struct actix_web::http::header::CacheControl [−][src]
pub struct CacheControl(pub Vec<CacheDirective>);
Cache-Control header, defined in RFC7234
The Cache-Control header field is used to specify directives for
caches along the request/response chain. Such cache directives are
unidirectional in that the presence of a directive in a request does
not imply that the same directive is to be given in the response.
ABNF
Cache-Control = 1#cache-directive
cache-directive = token [ "=" ( token / quoted-string ) ]
Example values
no-cacheprivate, community="UCI"max-age=30
Examples
use actix_web::HttpResponse; use actix_web::http::header::{CacheControl, CacheDirective}; let mut builder = HttpResponse::Ok(); builder.insert_header(CacheControl(vec![CacheDirective::MaxAge(86400u32)]));
use actix_web::HttpResponse; use actix_web::http::header::{CacheControl, CacheDirective}; let mut builder = HttpResponse::Ok(); builder.insert_header(CacheControl(vec![ CacheDirective::NoCache, CacheDirective::Private, CacheDirective::MaxAge(360u32), CacheDirective::Extension("foo".to_owned(), Some("bar".to_owned())), ]));