Struct actix_web::http::header::LastModified [−][src]
pub struct LastModified(pub HttpDate);
Last-Modified header, defined in
RFC7232
The Last-Modified header field in a response provides a timestamp
indicating the date and time at which the origin server believes the
selected representation was last modified, as determined at the
conclusion of handling the request.
ABNF
Expires = HTTP-date
Example values
Sat, 29 Oct 1994 19:43:31 GMT
Example
use std::time::{SystemTime, Duration}; use actix_web::HttpResponse; use actix_web::http::header::LastModified; let mut builder = HttpResponse::Ok(); let modified = SystemTime::now() - Duration::from_secs(60 * 60 * 24); builder.insert_header( LastModified(modified.into()) );