[−][src]Struct actix_web::http::header::Quality
Represents a quality used in quality values.
Can be created with the q function.
Implementation notes
The quality value is defined as a number between 0 and 1 with three decimal
places. This means there are 1001 possible values. Since floating point
numbers are not exact and the smallest floating point data type (f32)
consumes four bytes, hyper uses an u16 value to store the
quality internally. For performance reasons you may set quality directly to
a value between 0 and 1000 e.g. Quality(532) matches the quality
q=0.532.
RFC7231 Section 5.3.1 gives more information on quality values in HTTP header fields.