Struct actix_web::http::header::QualityItem [−][src]
pub struct QualityItem<T> {
pub item: T,
pub quality: Quality,
}Expand description
Represents an item with a quality value as defined in RFC7231.
Fields
item: TThe actual contents of the field.
quality: QualityThe quality (client or server preference) for the value.
Implementations
Creates a new QualityItem from an item and a quality.
The item can be of any type.
The quality should be a value in the range [0, 1].