Struct actix_web::http::Method [−][src]
pub struct Method(_);
The Request Method (VERB)
This type also contains constants for a number of common HTTP methods such as GET, POST, etc.
Currently includes 8 variants representing the 8 methods defined in RFC 7230, plus PATCH, and an Extension variant for all extensions.
Examples
use http::Method; assert_eq!(Method::GET, Method::from_bytes(b"GET").unwrap()); assert!(Method::GET.is_idempotent()); assert_eq!(Method::POST.as_str(), "POST");
Implementations
Converts a slice of bytes to an HTTP method.
Whether a method is considered “safe”, meaning the request is essentially read-only.
See the spec for more words.
Whether a method is considered “idempotent”, meaning the request has the same result if executed multiple times.
See the spec for more words.