[−][src]Struct actix_web::HttpRequest
An HTTP Request
Methods
impl HttpRequest[src]
pub fn head(&self) -> &RequestHead[src]
This method returns reference to the request head
pub fn uri(&self) -> &Uri[src]
Request's uri.
pub fn method(&self) -> &Method[src]
Read the Request method.
pub fn version(&self) -> Version[src]
Read the Request Version.
pub fn path(&self) -> &str[src]
The target path of this Request.
pub fn query_string(&self) -> &str[src]
The query string in the URL.
E.g., id=10
pub fn match_info(&self) -> &Path<Url>[src]
Get a reference to the Path parameters.
Params is a container for url parameters.
A variable segment is specified in the form {identifier},
where the identifier can be used later in a request handler to
access the matched value for that segment.
pub fn config(&self) -> &AppConfig[src]
App config
pub fn app_data<T: 'static>(&self) -> Option<Data<T>>[src]
Get an application data stored with App::data() method during
application configuration.
pub fn url_for<U, I>(
&self,
name: &str,
elements: U
) -> Result<Url, UrlGenerationError> where
U: IntoIterator<Item = I>,
I: AsRef<str>, [src]
&self,
name: &str,
elements: U
) -> Result<Url, UrlGenerationError> where
U: IntoIterator<Item = I>,
I: AsRef<str>,
Generate url for named resource
fn index(req: HttpRequest) -> HttpResponse { let url = req.url_for("foo", &["1", "2", "3"]); // <- generate url for "foo" resource HttpResponse::Ok().into() } fn main() { let app = App::new() .service(web::resource("/test/{one}/{two}/{three}") .name("foo") // <- set resource name, then it could be used in `url_for` .route(web::get().to(|| HttpResponse::Ok())) ); }
pub fn url_for_static(&self, name: &str) -> Result<Url, UrlGenerationError>[src]
Generate url for named resource
This method is similar to HttpRequest::url_for() but it can be used
for urls that do not contain variable parts.
pub fn connection_info(&self) -> Ref<ConnectionInfo>[src]
Get ConnectionInfo for the current request.
Methods from Deref<Target = RequestHead>
pub fn extensions(&self) -> Ref<Extensions>[src]
Message extensions
pub fn extensions_mut(&self) -> RefMut<Extensions>[src]
Mutable reference to a the message's extensions
pub fn headers(&self) -> &HeaderMap<HeaderValue>[src]
Read the message headers.
pub fn connection_type(&self) -> ConnectionType[src]
Connection type
pub fn upgrade(&self) -> bool[src]
Connection upgrade status
pub fn chunked(&self) -> bool[src]
Get response body chunking state