[−][src]Module actix_web::web
Essentials helper functions and types for application registration.
Structs
| Bytes | A reference counted contiguous slice of memory. |
| BytesMut | A unique reference to a contiguous slice of memory. |
| Canceled | Error returned from a |
| Data | Application data. |
| Form | Form data helper ( |
| FormConfig | Form extractor configuration |
| HttpRequest | An HTTP Request |
| HttpResponse | An HTTP Response |
| Json | Json helper |
| JsonConfig | Json extractor configuration |
| Path | Extract typed information from the request's path. |
| PathConfig | Path extractor configuration |
| Payload | Payload extractor returns request 's payload stream. |
| PayloadConfig | Configuration for request's payload. |
| Query | Extract typed information from the request's query. |
| QueryConfig | Query extractor configuration |
| Readlines | Stream to read request line by line. |
| ReqData | Request-local data extractor. |
| ServiceConfig | Service config is used for external configuration. Part of application configuration could be offloaded to set of external methods. This could help with modularization of big application configuration. |
Enums
| Either | Combines two different responder types into a single type |
| EitherExtractError | A composite error resulting from failure to extract an |
Traits
| Buf | Read bytes from a buffer. |
| BufMut | A trait for values that provide sequential write access to bytes. |
Functions
| block | Execute blocking function on a thread pool, returns future that resolves to result of the function execution. |
| delete | Create route with |
| get | Create route with |
| head | Create route with |
| method | Create route and add method guard. |
| patch | Create route with |
| post | Create route with |
| put | Create route with |
| resource | Create resource for a specific path. |
| route | Create route without configuration. |
| scope | Configure scope for common root path. |
| service | Create raw service for a specific path. |
| to | Create a new route and add handler. |
| trace | Create route with |