Struct actix_web::web::Form [−][src]
pub struct Form<T>(pub T);Expand description
Form data helper (application/x-www-form-urlencoded)
Can be use to extract url-encoded data from the request body, or send url-encoded data as the response.
Extract
To extract typed information from request’s body, the type T must
implement the Deserialize trait from serde.
FormConfig allows to configure extraction process.
Example
use actix_web::web;
use serde_derive::Deserialize;
#[derive(Deserialize)]
struct FormData {
username: String,
}
/// Extract form data using serde.
/// This handler get called only if content type is *x-www-form-urlencoded*
/// and content of the request could be deserialized to a `FormData` struct
fn index(form: web::Form<FormData>) -> String {
format!("Welcome {}!", form.username)
}Respond
The Form type also allows you to respond with well-formed url-encoded data:
simply return a value of type Formserde::Serialize;
Example
use actix_web::*;
use serde_derive::Serialize;
#[derive(Serialize)]
struct SomeForm {
name: String,
age: u8
}
// Will return a 200 response with header
// `Content-Type: application/x-www-form-urlencoded`
// and body "name=actix&age=123"
fn index() -> web::Form<SomeForm> {
web::Form(SomeForm {
name: "actix".into(),
age: 123
})
}Tuple Fields
0: TImplementations
Deconstruct to an inner value