pub struct Json<T>(pub T);Expand description
JSON extractor and responder.
Json has two uses: JSON responses, and extracting typed data from JSON request payloads.
Extractor
To extract typed data from a request body, the inner type T must implement the
serde::Deserialize trait.
Use JsonConfig to configure extraction options.
use actix_web::{post, web, App};
use serde::Deserialize;
#[derive(Deserialize)]
struct Info {
username: String,
}
/// deserialize `Info` from request's body
#[post("/")]
async fn index(info: web::Json<Info>) -> String {
format!("Welcome {}!", info.username)
}Responder
The Json type JSON formatted responses. A handler may return a value of type
Json<T> where T is the type of a structure to serialize into JSON. The type T must
implement serde::Serialize.
use actix_web::{post, web, HttpRequest};
use serde::Serialize;
#[derive(Serialize)]
struct Info {
name: String,
}
#[post("/{name}")]
async fn index(req: HttpRequest) -> web::Json<Info> {
web::Json(Info {
name: req.match_info().get("name").unwrap().to_owned(),
})
}Tuple Fields
0: TImplementations
Unwrap into inner T value.