Struct actix_web::web::PayloadConfig
source · [−]pub struct PayloadConfig { /* private fields */ }Expand description
Configuration for request payloads.
Applies to the built-in Bytes and String extractors.
Note that the Payload extractor does not automatically check
conformance with this configuration to allow more flexibility when
building extractors on top of Payload.
By default, the payload size limit is 256kB and there is no mime type condition.
To use this, add an instance of it to your app, scope
or resource through the associated .app_data() method.
Implementations
sourceimpl PayloadConfig
impl PayloadConfig