Struct actix_web::web::PayloadConfig [−][src]
pub struct PayloadConfig { /* fields omitted */ }Expand description
Configuration for request payloads.
Applies to the built-in Bytes and String extractors. Note that the Payload extractor does
not automatically check conformance with this configuration to allow more flexibility when
building extractors on top of Payload.
By default, the payload size limit is 256kB and there is no mime type condition.
To use this, add an instance of it to your app or service through one of the
.app_data() methods.
Implementations
Create new instance with a size limit (in bytes) and no mime type condition.
Set maximum accepted payload size in bytes. The default limit is 256kB.